# tb-go
**@readwithai** - [X](https://x.com/readwithai) - [blog](https://readwithai.substack.com/) - [machine-aided reading](https://www.reddit.com/r/machineAidedReading/) - [📖](https://readwithai.substack.com/p/what-is-reading-broadly-defined)[⚡️](https://readwithai.substack.com/s/technical-miscellany)[🖋️](https://readwithai.substack.com/p/note-taking-with-obsidian-much-of)


Traceback go.

Go to lines in a traceback from the command-line.

Warning: this is vibe coded - but will likely get less so over time.


## Motivation
I have been doing vibe code recently and using a full editor feels a bit heavy weight (another window to be aware of). So I am doing more things at the command-line with vim. But clickable tracebacks are really nice so I an adding this the shell.

## Installation
You can install `tb-go` with pipx.

```
pipx install tb-go
```

## Usage
You can run `tb-go` and paste a traceback into it (on linux middle click is your friend here).

Alternatively you can use it as a wrapper with `tb-go python script.py`


## Alternatives and prior work
Python provides programmatic handlers for tracebacks. You could use one of these rather than parsing erorrs.

Many IDEs have this feature. I have implemented it in emacs with compile mode.

Django has clickable tracebacks.

## About me

I am **@readwithai**. I create tools for reading, research and agency sometimes using the markdown editor [Obsidian](https://readwithai.substack.com/p/what-exactly-is-obsidian).

I also create a [stream of tools](https://readwithai.substack.com/p/my-productivity-tools) that are related to carrying out my work. You may be interested in some of these tools.

I write about lots of things - including tools like this - on [X](https://x.com/readwithai).
My [blog](https://readwithai.substack.com/) is more about reading and research and agency.





